==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/igr-data-chart-annotation-module.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationFactoryManager } from './AnnotationFactoryManager';
import { IgrCrosshairLayerModule } from './igr-crosshair-layer-module';
import { IgrCategoryToolTipLayerModule } from './igr-category-tool-tip-layer-module';
import { IgrItemToolTipLayerModule } from './igr-item-tool-tip-layer-module';
import { IgrCategoryItemHighlightLayerModule } from './igr-category-item-highlight-layer-module';
import { IgrCategoryHighlightLayerModule } from './igr-category-highlight-layer-module';
import { IgrFinalValueLayerModule } from './igr-final-value-layer-module';
import { IgrCalloutLayerModule } from './igr-callout-layer-module';
import { IgrSummaryToolTipLayerModule } from './igr-summary-tool-tip-layer-module';
import { TypeRegistrar } from "igniteui-react-core";
var IgrDataChartAnnotationModule = /** @class */ /*@__PURE__*/ (function () {
    function IgrDataChartAnnotationModule() {
    }
    IgrDataChartAnnotationModule.register = function () {
        TypeRegistrar.register('AnnotationFactoryManager', AnnotationFactoryManager.$type);
        IgrCrosshairLayerModule.register();
        IgrCategoryToolTipLayerModule.register();
        IgrItemToolTipLayerModule.register();
        IgrCategoryItemHighlightLayerModule.register();
        IgrCategoryHighlightLayerModule.register();
        IgrFinalValueLayerModule.register();
        IgrCalloutLayerModule.register();
        IgrSummaryToolTipLayerModule.register();
    };
    return IgrDataChartAnnotationModule;
}());
export { IgrDataChartAnnotationModule };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-data-chart-annotation-module.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationFactoryManager } from './AnnotationFactoryManager';
import { IgrCrosshairLayerModule } from './igr-crosshair-layer-module';
import { IgrCategoryToolTipLayerModule } from './igr-category-tool-tip-layer-module';
import { IgrItemToolTipLayerModule } from './igr-item-tool-tip-layer-module';
import { IgrCategoryItemHighlightLayerModule } from './igr-category-item-highlight-layer-module';
import { IgrCategoryHighlightLayerModule } from './igr-category-highlight-layer-module';
import { IgrFinalValueLayerModule } from './igr-final-value-layer-module';
import { IgrCalloutLayerModule } from './igr-callout-layer-module';
import { IgrDataToolTipLayerModule } from './igr-data-tool-tip-layer-module';
import { TypeRegistrar } from "igniteui-react-core";
var IgrDataChartAnnotationModule = /** @class */ /*@__PURE__*/ (function () {
    function IgrDataChartAnnotationModule() {
    }
    IgrDataChartAnnotationModule.register = function () {
        TypeRegistrar.register('AnnotationFactoryManager', AnnotationFactoryManager.$type);
        IgrCrosshairLayerModule.register();
        IgrCategoryToolTipLayerModule.register();
        IgrItemToolTipLayerModule.register();
        IgrCategoryItemHighlightLayerModule.register();
        IgrCategoryHighlightLayerModule.register();
        IgrFinalValueLayerModule.register();
        IgrCalloutLayerModule.register();
        IgrDataToolTipLayerModule.register();
    };
    return IgrDataChartAnnotationModule;
}());
export { IgrDataChartAnnotationModule };
